# 提供爬虫参数 #
### 更新内容: ###
1. cookies 模块兼容 Windows7 用户.
2. cookies rgetcookies() 函数增加安全连接选项, 并优化体验.
3. rgetcookies() 函数完善 url 参数填写, 增加 parmas 可选选项增加获取 cookies 的准确性.

# Provide crawler parameters #
### Update content: ###
1. The cookies module is compatible with Windows 7 users.
2. The cookies rgetcookies() function adds a secure connection option, And optimize the experience.
3. The rgetcookies() function improves the filling of URL parameters and adds optional options for parmas to increase the accuracy of obtaining cookies.
